@@ -10,7 +10,7 @@ do
   # echo ${dir} "=>" ${python_package}
   cd ${dir}
   if [ "$(find -maxdepth 1 -type f -iname '*.ksy')" ]; then
-    kaitai-struct-compiler -t python --python-package ${python_package} *.ksy
+    bash -x -c "kaitai-struct-compiler -t python --python-package ${python_package} *.ksy"
     black .
   fi
   cd ${dirbase}
